==> thirdparty-service-biz-0.0.1-20161206.064205-1-sources.jar: cn/com/duiba/domain/SupplierRequest.java <==
package cn.com.duiba.domain;

import java.util.Map;

/**
 * 消息封装类
 */
public class SupplierRequest {

	private String orderId;
	private String supplierOrderId;
	private String supplierName;
	private String bizType;
	private String appId;
	private String consumerId;
	private String httpUrl;
	private Map<String, String> authParams;
	private Map<String, String> params;

	public String getOrderId() {
		return orderId;
	}

	public void setOrderId(String orderId) {
		this.orderId = orderId;
	}

	public String getSupplierOrderId() {
		return supplierOrderId;
	}

	public void setSupplierOrderId(String supplierOrderId) {
		this.supplierOrderId = supplierOrderId;
	}

	public String getSupplierName() {
		return supplierName;
	}

	public void setSupplierName(String supplierName) {
		this.supplierName = supplierName;
	}

	public String getBizType() {
		return bizType;
	}

	public void setBizType(String bizType) {
		this.bizType = bizType;
	}

	public String getAppId() {
		return appId;
	}

	public void setAppId(String appId) {
		this.appId = appId;
	}

	public String getConsumerId() {
		return consumerId;
	}

	public void setConsumerId(String consumerId) {
		this.consumerId = consumerId;
	}

	public String getHttpUrl() {
		return httpUrl;
	}

	public void setHttpUrl(String httpUrl) {
		this.httpUrl = httpUrl;
	}

	public Map<String, String> getParams() {
		return params;
	}

	public void setParams(Map<String, String> params) {
		this.params = params;
	}

	public Map<String, String> getAuthParams() {
		return authParams;
	}

	public void setAuthParams(Map<String, String> authParams) {
		this.authParams = authParams;
	}

}

==> thirdparty-service-biz-1.0.59-20220623.034212-1-sources.jar: cn/com/duiba/domain/SupplierRequest.java <==
package cn.com.duiba.domain;

import java.util.Map;

/**
 * 上游请求消息封装类
 */
public class SupplierRequest {

	private String orderId;
	private String supplierOrderId;
	private String supplierName;
	private String bizType;
	private String appId;
	private String consumerId;
	private String httpUrl;
	private Map<String, String> authParams;

	/**
	 * 支持object类型传递
	 */
	private Map<String, Object> authDatas;
	private Map<String, String> params;
	/**
	 * 当虚拟商品为加积分商品时是否保存对账记录，用于有对账需求的开发者
	 */
	private boolean isSaveReconciliationRecord=false;


	public boolean isSaveReconciliationRecord() {
		return isSaveReconciliationRecord;
	}

	public void setSaveReconciliationRecord(boolean saveReconciliationRecord) {
		isSaveReconciliationRecord = saveReconciliationRecord;
	}

	public Map<String, Object> getAuthDatas() {
		return authDatas;
	}

	public void setAuthDatas(Map<String, Object> authDatas) {
		this.authDatas = authDatas;
	}

	public String getOrderId() {
		return orderId;
	}

	public void setOrderId(String orderId) {
		this.orderId = orderId;
	}

	public String getSupplierOrderId() {
		return supplierOrderId;
	}

	public void setSupplierOrderId(String supplierOrderId) {
		this.supplierOrderId = supplierOrderId;
	}

	public String getSupplierName() {
		return supplierName;
	}

	public void setSupplierName(String supplierName) {
		this.supplierName = supplierName;
	}

	public String getBizType() {
		return bizType;
	}

	public void setBizType(String bizType) {
		this.bizType = bizType;
	}

	public String getAppId() {
		return appId;
	}

	public void setAppId(String appId) {
		this.appId = appId;
	}

	public String getConsumerId() {
		return consumerId;
	}

	public void setConsumerId(String consumerId) {
		this.consumerId = consumerId;
	}

	public String getHttpUrl() {
		return httpUrl;
	}

	public void setHttpUrl(String httpUrl) {
		this.httpUrl = httpUrl;
	}

	public Map<String, String> getParams() {
		return params;
	}

	public void setParams(Map<String, String> params) {
		this.params = params;
	}

	public Map<String, String> getAuthParams() {
		return authParams;
	}

	public void setAuthParams(Map<String, String> authParams) {
		this.authParams = authParams;
	}

}
